EnvironmentType enum

Environment types for build configuration Can be set via --dart-define=ENVIRONMENT_TYPE=production

Inheritance
Available extensions

Values

emulator → const EnvironmentType
const EnvironmentType('emulator')
development → const EnvironmentType
const EnvironmentType('development')
test → const EnvironmentType
const EnvironmentType('test')
staging → const EnvironmentType
const EnvironmentType('staging')
production → const EnvironmentType
const EnvironmentType('production')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) EnvironmentType

Constants

values → const List<EnvironmentType>
A constant List of the values in this enum, in order of their declaration.