AppState class

Constructors

AppState({AppAuthStatus appAuthStatus = AppAuthStatus.noauth, AppStatus appStatus = AppStatus.normal, double progress = 0.0, String progressHeaderText = '', String currentPath = '', int colorThemeIndex = 0, List<Widget Function()>? overlayFullScreenChild, int overlayFullScreenChildCount = 0, NetworkStatus networkStatus = NetworkStatus.unknown, String networkErrorMessage = '', bool showNetworkRetry = false, VersionUpdateInfo? versionUpdateInfo, bool showVersionUpdateBanner = false, int unreadNotificationCount = 0, NotificationPermissionStatus notificationPermissionStatus = NotificationPermissionStatus.notDetermined})
const

Properties

appAuthStatus AppAuthStatus
final
appStatus AppStatus
final
colorThemeIndex int
final
currentPath String
final
hashCode int
The hash code for this object.
no setterinherited
networkErrorMessage String
final
networkStatus NetworkStatus
final
notificationPermissionStatus NotificationPermissionStatus
The current notification permission status.
final
overlayFullScreenChild List<Widget Function()>?
final
overlayFullScreenChildCount int
final
progress double
final
progressHeaderText String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNetworkRetry bool
final
showVersionUpdateBanner bool
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unreadNotificationCount int
The number of unread notifications (used for badge display).
final
versionUpdateInfo VersionUpdateInfo?
final

Methods

copyWith({AppAuthStatus? appAuthStatus, AppStatus? appStatus, double? progress, String? progressHeaderText, String? currentPath, int? colorThemeIndex, ValueGetter<List<Widget Function()>>? overlayFullScreenChild, int? overlayFullScreenChildCount, NetworkStatus? networkStatus, String? networkErrorMessage, bool? showNetworkRetry, VersionUpdateInfo? versionUpdateInfo, bool? showVersionUpdateBanner, int? unreadNotificationCount, NotificationPermissionStatus? notificationPermissionStatus}) AppState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited