tokenAutoRefreshEnabled property
Whether to enable automatic token refresh after activation (default true).
Implementation
final bool tokenAutoRefreshEnabled;
Whether to enable automatic token refresh after activation (default true).
final bool tokenAutoRefreshEnabled;