bufferEarlyErrorForTest function

  1. @visibleForTesting
void bufferEarlyErrorForTest(
  1. Object error, [
  2. StackTrace? stackTrace
])

Test-only seam to push an error into the buffer as the early handlers would, so the bounded-buffer / flush tests do not need to drive real FlutterError.onError (Issue 16/82).

Implementation

@visibleForTesting
void bufferEarlyErrorForTest(Object error, [StackTrace? stackTrace]) {
  _bufferEarlyError(error, stackTrace);
}