WebRemoteConfigRefreshService class

Annotations
  • @Deprecated('No longer needed - onConfigUpdated now works on web (firebase_remote_config 6.1.0+)')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Stop the refresh service
forceRefresh() Future<void>
Force an immediate refresh (bypassing rate limits) Use sparingly due to Firebase's 5 fetches/hour limit
getStatus() Map<String, dynamic>
Get current status of the service
initialize() Future<void>
Initialize the web refresh service This should be called after Remote Config initialization on web platforms only
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WebRemoteConfigRefreshService
no setter