SmartTimestampConverterNotNull class

Non-nullable version of SmartTimestampConverter.

Use this for non-nullable DateTime fields. Returns epoch (1970-01-01) if parsing fails.

Example:

@SmartTimestampConverterNotNull()
final DateTime timestamp;

Constructors

SmartTimestampConverterNotNull()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(dynamic data) DateTime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(DateTime dateTime) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited