TimestampMillisNullableConverter class

Converts nullable DateTime to/from milliseconds since epoch (function-safe)

Constructors

TimestampMillisNullableConverter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Object? timestamp) DateTime?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(DateTime? date) int?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited