data/helpers/repo_helpers library
Classes
Functions
-
safeResultData(
HttpsCallableResult result) → Map< String, dynamic> - Safely extracts a Map from a Cloud Function result. Throws StateError if the response is not a Map — callers are expected to catch this via their existing try/catch → RepositoryFailure.unexpected.