SortingHelpers2 class

Constructors

SortingHelpers2()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calculateNewSortOrder2<T extends Sortable2>(List<T> items, int oldIndex, int newIndex, SortOrderType sortOrderType) → double
findHighestSortOrder<T extends Sortable2>(List<T> items, SortOrderType sortOrderType) → double
findLowestSortOrder<T extends Sortable2>(List<T> items, SortOrderType sortOrderType) → double
reorderItems<T extends Sortable2>(List<T> items, int oldIndex, int newIndex, SortOrderType sortOrderType) → int