AuthAwareStreamSubscription<T> class

Wraps a stream and automatically cancels it when the user signs out

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause([Future<void>? resumeSignal]) → void
resume() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

listen<T>(Stream<T> stream, void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError}) → AuthAwareStreamSubscription<T>