DeviceFormFactor enum

Physical form factor of the device.

This represents the physical device type, which is orthogonal to DevicePlatform. An iPad is platform "ios" but form factor "tablet". Used by the server-side delivery strategy system to prioritize which devices receive notifications.

Inheritance
Available extensions

Values

phone → const DeviceFormFactor

Phone (iPhone, Android phone)

tablet → const DeviceFormFactor

Tablet (iPad, Android tablet)

desktop → const DeviceFormFactor

Desktop native app (macOS, Windows, Linux)

browser → const DeviceFormFactor

Web browser (any OS)

Properties

displayName String

Available on DeviceFormFactor, provided by the DeviceFormFactorExtension extension

Returns a human-readable display name for this form factor.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DeviceFormFactor>
A constant List of the values in this enum, in order of their declaration.