appVersion property
App version installed on this device.
Useful for debugging and ensuring notifications are compatible with the installed app version.
Implementation
final String? appVersion;
App version installed on this device.
Useful for debugging and ensuring notifications are compatible with the installed app version.
final String? appVersion;