createdAt property
When this device was first registered.
Set once on initial device registration and never updated.
Implementation
@SmartTimestampConverter()
final DateTime? createdAt;
When this device was first registered.
Set once on initial device registration and never updated.
@SmartTimestampConverter()
final DateTime? createdAt;