DevicePlatform enum

Supported device platforms for device tracking.

This enum represents the platforms where the app can run and be tracked by the DeviceService. It includes mobile, desktop, and web platforms.

Inheritance
Available extensions

Values

ios → const DevicePlatform

iOS devices (iPhone, iPad)

android → const DevicePlatform

Android devices

web → const DevicePlatform

Web browsers

macos → const DevicePlatform

macOS desktop

windows → const DevicePlatform

Windows desktop

linux → const DevicePlatform

Linux desktop

Properties

displayName String

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns a human-readable display name for this platform.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isDesktop bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is a desktop platform (macOS, Windows, or Linux).
no setter
isMobile bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is a mobile platform (iOS or Android).
no setter
isWeb bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is the web platform.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DevicePlatform>
A constant List of the values in this enum, in order of their declaration.