isMobile property
bool
get
isMobile
Returns true if this is a mobile platform (iOS or Android).
Implementation
bool get isMobile => this == DevicePlatform.ios || this == DevicePlatform.android;
Returns true if this is a mobile platform (iOS or Android).
bool get isMobile => this == DevicePlatform.ios || this == DevicePlatform.android;