deserialize static method

DevicePlatform? deserialize(
  1. String? value
)

Deserializes a DevicePlatform from JSON, returning null for unknown values.

This is a safe deserializer that will not throw on unknown values, making the app resilient to new platform values from the backend.

Implementation

static DevicePlatform? deserialize(String? value) {
  return safeEnumFromJson<DevicePlatform>(
    value,
    DevicePlatform.values,
  );
}