channelId property
Notification channel ID (Android only).
Determines the notification channel that should be used. If not specified, the default channel will be used.
Implementation
final String? channelId;
Notification channel ID (Android only).
Determines the notification channel that should be used. If not specified, the default channel will be used.
final String? channelId;