imageUrl property

String? imageUrl
final

URL to an image to display in the notification.

The image will be downloaded and cached before displaying the notification. If download fails, the notification will be displayed without the image.

Implementation

final String? imageUrl;