ttl property
Time-to-live for the notification in seconds.
Determines how long the notification should be retained if the device is offline. After this period, the notification expires.
Implementation
final int? ttl;
Time-to-live for the notification in seconds.
Determines how long the notification should be retained if the device is offline. After this period, the notification expires.
final int? ttl;