useFirebaseFCM property

bool useFirebaseFCM
getter/setter pair

Whether to use Firebase FCM for push notifications This is the general setting, which can be disabled by the app config setting, but not overridden to enable FCM by the app config.

Implementation

bool useFirebaseFCM;