AuthServiceActionCodeFailure enum

Inheritance
Available extensions

Values

invalidCode → const AuthServiceActionCodeFailure

Code is malformed, never issued, or already consumed.

expiredCode → const AuthServiceActionCodeFailure

Code has expired (typically ~1h for email verification).

userDisabled → const AuthServiceActionCodeFailure

Associated user account is disabled.

userNotFound → const AuthServiceActionCodeFailure

No user account exists for the action (rare; user deleted between issue and use).

unexpected → const AuthServiceActionCodeFailure

Network or other unexpected failure.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthServiceActionCodeFailure>
A constant List of the values in this enum, in order of their declaration.