removeOnAuthenticatedCallback abstract method
Remove a previously added authenticated callback. Returns true if the callback was found and removed.
Implementation
bool removeOnAuthenticatedCallback(Future<void> Function(String? uid) callback);
Remove a previously added authenticated callback. Returns true if the callback was found and removed.
bool removeOnAuthenticatedCallback(Future<void> Function(String? uid) callback);