AuthServiceLinkFailure enum
Failure cases for linking anonymous accounts to credentials
Values
- userNotLoggedIn → const AuthServiceLinkFailure
-
User is not logged in or not anonymous
- emailAlreadyInUse → const AuthServiceLinkFailure
-
The email is already in use by another account
- weakPassword → const AuthServiceLinkFailure
-
Password is too weak (less than 6 characters)
- invalidEmail → const AuthServiceLinkFailure
-
The email address is invalid
- invalidCredential → const AuthServiceLinkFailure
-
The credential is invalid or has expired
- requiresRecentLogin → const AuthServiceLinkFailure
-
Account requires recent authentication before linking
- credentialAlreadyInUse → const AuthServiceLinkFailure
-
The credential is already associated with a different user account
- unexpected → const AuthServiceLinkFailure
-
General unexpected error
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthServiceLinkFailure> - A constant List of the values in this enum, in order of their declaration.