AuthServiceSignInFailure enum
Values
- invalidEmail → const AuthServiceSignInFailure
- userNotFound → const AuthServiceSignInFailure
- wrongPassword → const AuthServiceSignInFailure
- weakPassword → const AuthServiceSignInFailure
- userDisabled → const AuthServiceSignInFailure
- userAlreadyExists → const AuthServiceSignInFailure
- databaseError → const AuthServiceSignInFailure
- unexpected → const AuthServiceSignInFailure
- tooManyRequests → const AuthServiceSignInFailure
- invalidCredential → const AuthServiceSignInFailure
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthServiceSignInFailure> - A constant List of the values in this enum, in order of their declaration.