error_reporting/error_reporter_interface library

Classes

ErrorReporter
Interface for external error reporting services Implement this interface to integrate custom error reporting solutions like Sentry, Bugsnag, or other crash reporting services.
ErrorReporterUserContext
Optional interface for error reporters that support user context.
ErrorReportingConfig
Configuration for error reporting