recordValuePropDecline method

Future<void> recordValuePropDecline()

Records a value-proposition decline.

Apps that show their own value-proposition UI outside the built-in flow can call this to participate in the same bookkeeping. Apps that use runNotificationPermissionFlow do not need to call this — it is invoked automatically when the flow returns NotificationFlowResult.declinedValueProposition. Delegates to NotificationPermissionHelper.recordValuePropDecline.

Implementation

Future<void> recordValuePropDecline() =>
    _permissionHelper.recordValuePropDecline();