GoToSettingsPromptInfo class

Information about "go to settings" prompts shown to user.

Used to implement configurable limits on how often to prompt users to enable notifications via settings.

Constructors

GoToSettingsPromptInfo({required DateTime lastPromptTime, required int promptCount, required bool lastActionWasOpenSettings})
const
GoToSettingsPromptInfo.fromJson(Map<String, dynamic> json)
Creates a GoToSettingsPromptInfo from JSON.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastActionWasOpenSettings → bool
Whether user declined (false) or opened settings (true) last time.
final
lastPromptTime → DateTime
When the user was last shown the "go to settings" prompt.
final
promptCount → int
Total number of times the prompt was shown.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DateTime? lastPromptTime, int? promptCount, bool? lastActionWasOpenSettings}) → GoToSettingsPromptInfo
Creates a copy of this GoToSettingsPromptInfo with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this GoToSettingsPromptInfo to JSON.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited