lastRequestWasBlocked property
Whether the last request was blocked by the system (no dialog shown).
Implementation
final bool lastRequestWasBlocked;
Whether the last request was blocked by the system (no dialog shown).
final bool lastRequestWasBlocked;