requestAttemptCount property
Total number of times we attempted to request permission. (may be higher than denialCount if some requests were blocked)
Implementation
final int requestAttemptCount;
Total number of times we attempted to request permission. (may be higher than denialCount if some requests were blocked)
final int requestAttemptCount;