showGoToSettingsPrompt property
Whether to show the "go to settings" prompt at all when permanently denied. Set to false if your app should never prompt users to change settings. Default: true
Implementation
final bool showGoToSettingsPrompt;
Whether to show the "go to settings" prompt at all when permanently denied. Set to false if your app should never prompt users to change settings. Default: true
final bool showGoToSettingsPrompt;