NotificationFlowStrings class

Strings for the notification permission flow dialogs.

Provide localized versions of these for your app.

Constructors

NotificationFlowStrings({String valuePropositionTitle = 'Enable Notifications', String valuePropositionMessage = 'Stay updated with important alerts and messages.', String valuePropositionAcceptButton = 'Enable', String valuePropositionDeclineButton = 'Not Now', String goToSettingsTitle = 'Notifications Disabled', String goToSettingsMessage = 'To receive notifications, please enable them in your device settings.', String goToSettingsButton = 'Open Settings', String goToSettingsCancelButton = 'Cancel', String askAgainTitle = 'Enable Notifications?', String askAgainMessage = 'You previously declined notifications. Would you like to enable them now?', String askAgainAcceptButton = 'Yes, Enable', String askAgainDeclineButton = 'No Thanks', String webSettingsInstructionsTitle = 'Enable Notifications', String webSettingsInstructionsMessage = 'To enable notifications:\n\n' "1. Click the lock/info icon in your browser's address bar\n" '2. Find "Notifications" in the permissions list\n' '3. Change it from "Block" to "Allow"\n' '4. Refresh this page', String webSettingsInstructionsButton = 'Got It'})
const

Properties

askAgainAcceptButton → String
final
askAgainDeclineButton → String
final
askAgainMessage → String
final
askAgainTitle → String
final
goToSettingsButton → String
final
goToSettingsCancelButton → String
final
goToSettingsMessage → String
final
goToSettingsTitle → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valuePropositionAcceptButton → String
final
valuePropositionDeclineButton → String
final
valuePropositionMessage → String
final
valuePropositionTitle → String
final
webSettingsInstructionsButton → String
final
webSettingsInstructionsMessage → String
final
webSettingsInstructionsTitle → String
final

Methods

copyWith({String? valuePropositionTitle, String? valuePropositionMessage, String? valuePropositionAcceptButton, String? valuePropositionDeclineButton, String? goToSettingsTitle, String? goToSettingsMessage, String? goToSettingsButton, String? goToSettingsCancelButton, String? askAgainTitle, String? askAgainMessage, String? askAgainAcceptButton, String? askAgainDeclineButton, String? webSettingsInstructionsTitle, String? webSettingsInstructionsMessage, String? webSettingsInstructionsButton}) → NotificationFlowStrings
Creates a copy of this NotificationFlowStrings with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited