NotificationInitResult enum

Result of initializing notifications.

Returned by NotificationService.initializeNotifications to indicate the outcome of the initialization attempt.

Inheritance
Available extensions

Values

success → const NotificationInitResult

Successfully initialized and permission granted.

permissionDenied → const NotificationInitResult

User denied notification permission (may be able to request again on Android).

permissionPermanentlyDenied → const NotificationInitResult

Permission permanently denied - must direct user to system settings. (iOS after first denial, Android after "Don't ask again")

permissionRequestBlocked → const NotificationInitResult

Permission request was blocked by the system (OEM restriction, etc.). The user never saw the dialog - don't count as a denial.

fcmDisabledInstance → const NotificationInitResult

FCM is disabled in this AuthService instance.

fcmDisabledConfig → const NotificationInitResult

FCM is disabled in AppConfigBase.

alreadyInitialized → const NotificationInitResult

Already initialized.

error → const NotificationInitResult

Initialization failed due to an error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NotificationInitResult>
A constant List of the values in this enum, in order of their declaration.