channelId property
Android notification channel ID if the user navigated from a specific channel's settings page. Null on iOS or when opened from the app's general notification settings.
Implementation
final String? channelId;
Android notification channel ID if the user navigated from a specific channel's settings page. Null on iOS or when opened from the app's general notification settings.
final String? channelId;