showOnInitialConnection property
Whether to show the connecting toast during initial connection check (when transitioning from unknown to none). Defaults to false to avoid showing toast on every app resume.
Implementation
final bool showOnInitialConnection;