isLabelVisible property
Whether the badge is enabled. When false, only the child is displayed without the badge. Defaults to true.
Implementation
final bool isLabelVisible;
Whether the badge is enabled. When false, only the child is displayed without the badge. Defaults to true.
final bool isLabelVisible;