NotificationPermissionBottomSheet constructor

const NotificationPermissionBottomSheet({
  1. Key? key,
  2. String title = 'Enable Notifications',
  3. String description = 'Stay informed with notifications about important updates and activity.',
  4. String allowButtonText = 'Allow Notifications',
  5. String declineButtonText = 'Not Now',
  6. String deniedDialogTitle = 'Notifications Disabled',
  7. String deniedDialogMessage = 'To enable notifications, please go to Settings and allow notifications for this app.',
  8. String openSettingsButtonText = 'Open Settings',
  9. String maybeLaterButtonText = 'Maybe Later',
  10. Color? primaryColor,
  11. Color? backgroundColor,
  12. Widget? icon,
  13. dynamic onResult(
    1. NotificationPermissionStatus
    )?,
})

Implementation

const NotificationPermissionBottomSheet({
  super.key,
  this.title = 'Enable Notifications',
  this.description = 'Stay informed with notifications about important updates and activity.',
  this.allowButtonText = 'Allow Notifications',
  this.declineButtonText = 'Not Now',
  this.deniedDialogTitle = 'Notifications Disabled',
  this.deniedDialogMessage =
      'To enable notifications, please go to Settings and allow notifications for this app.',
  this.openSettingsButtonText = 'Open Settings',
  this.maybeLaterButtonText = 'Maybe Later',
  this.primaryColor,
  this.backgroundColor,
  this.icon,
  this.onResult,
});