NotificationPermissionBuilder class

A builder widget that provides notification permission state and actions.

This is a headless component that provides permission status and request functionality to your custom UI via a builder callback. The builder automatically rebuilds when permission status changes.

Example:

NotificationPermissionBuilder(
  builder: (context, status, requestPermissions) {
    if (status == NotificationPermissionStatus.authorized) {
      return Text('Notifications enabled!');
    }
    return ElevatedButton(
      onPressed: requestPermissions,
      child: Text('Enable Notifications'),
    );
  },
)

You can also use it to conditionally show content:

NotificationPermissionBuilder(
  builder: (context, status, requestPermissions) {
    return Column(
      children: [
        Text('Status: ${status.name}'),
        if (status != NotificationPermissionStatus.authorized)
          OutlinedButton(
            onPressed: requestPermissions,
            child: Text('Enable'),
          ),
        if (status == NotificationPermissionStatus.authorized)
          NotificationListWidget(),
      ],
    );
  },
)
Inheritance
Available extensions

Constructors

NotificationPermissionBuilder({Key? key, required Widget builder(BuildContext context, NotificationPermissionStatus status, Future<void> requestPermissions()), void onStatusChanged(NotificationPermissionStatus status)?})
const

Properties

builder Widget Function(BuildContext context, NotificationPermissionStatus status, Future<void> requestPermissions())
Builder callback that provides permission status and request method.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onStatusChanged → void Function(NotificationPermissionStatus status)?
Optional callback when permission status changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NotificationPermissionBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withUpdateDebugControls() Widget

Available on Widget, provided by the AppUpdateDebugExtension extension

Wraps this widget with debug controls if in debug mode

Operators

operator ==(Object other) bool
The equality operator.
inherited