NotificationPermissionStatusWidget class

A widget that displays the current notification permission status.

Automatically updates when permission status changes and provides action buttons based on the current state.

Usage

Basic usage:

NotificationPermissionStatusWidget()

With custom actions:

NotificationPermissionStatusWidget(
  onEnablePressed: () async {
    // Show custom permission flow
  },
  onSettingsPressed: () async {
    // Custom settings navigation
  },
)
Inheritance
Available extensions

Constructors

NotificationPermissionStatusWidget({Key? key, VoidCallback? onEnablePressed, VoidCallback? onSettingsPressed, EdgeInsets? padding, bool showActionButton = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEnablePressed VoidCallback?
final
onSettingsPressed VoidCallback?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActionButton bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NotificationPermissionStatusWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withUpdateDebugControls() Widget

Available on Widget, provided by the AppUpdateDebugExtension extension

Wraps this widget with debug controls if in debug mode

Operators

operator ==(Object other) bool
The equality operator.
inherited