TapConcurrencyMode enum
Concurrency control for async tap handlers.
Values
- drop → const TapConcurrencyMode
-
Ignore new taps while processing (default).
- replace → const TapConcurrencyMode
-
Cancel current operation and start new one.
- keepLatest → const TapConcurrencyMode
-
Keep current + latest only, drop intermediate.
- enqueue → const TapConcurrencyMode
-
Queue all taps, execute sequentially (FIFO).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TapConcurrencyMode> - A constant List of the values in this enum, in order of their declaration.