MockAppCubit class

Mock AppCubit for widget testing

Provides minimal AppState for widgets that depend on AppCubit context. Use wrapWithMockAppCubit helper for easy test setup.

Example:

await tester.pumpWidget(
  wrapWithMockAppCubit(
    MaterialApp(
      home: MyWidget(),
    ),
  ),
);
Inheritance

Constructors

MockAppCubit({NetworkStatus networkStatus = NetworkStatus.connected, AppAuthStatus authStatus = AppAuthStatus.noauth, AppStatus appStatus = AppStatus.normal})

Properties

connectionChecker ↔ InternetConnection?
getter/setter pairinherited
connectionCheckerSubscription StreamSubscription?
getter/setter pairinherited
entranceUri Uri?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasProcessedEntrance bool
getter/setter pairinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
lifecycleSubscription StreamSubscription<AppLifecycleState>?
getter/setter pairinherited
networkRequired bool
getter/setter pairinherited
notificationBadgeSubscription StreamSubscription<int>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AppState
The current state.
no setterinherited
stream Stream<AppState>
The current stream of states.
no setterinherited
versionUpdateSubscription StreamSubscription<VersionUpdateInfo>?
getter/setter pairinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
checkForAppUpdates() Future<void>
inherited
clearUnreadNotificationCount() → void
Clears the unread notification count (sets to 0).
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
override
dismissVersionUpdateBanner() → void
inherited
emit(AppState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
emitSafe(AppState state) → void
inherited
getInitialData() Future<void>
override
incrementUnreadNotificationCount() → void
Increments the unread notification count by 1.
inherited
initializeNotificationSync() Future<void>
Initializes notification state sync with NotificationService.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<AppState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onNavHappened(String path) Future<void>
inherited
overlayFullScreenFinish() → void
inherited
overlayFullScreenSetChild(Widget child()) → void
inherited
overlayFullScreenSetChildAndStart(Widget child()?) → void
inherited
overlayFullScreenStart() → void
inherited
overlayLoadingFinish() → void
inherited
overlayLoadingStart() → void
inherited
overlayProgressingFinish() → void
inherited
overlayProgressingStart({String? headerText}) → void
inherited
overlayProgressingUpdate(double progress) → void
inherited
refreshNotificationPermissionStatus() Future<void>
Refreshes the notification permission status from the system.
inherited
requestNotificationPermissions({bool provisional = false}) Future<NotificationPermissionStatus>
Requests notification permissions and syncs the result to state.
inherited
retryNetworkConnection() Future<void>
inherited
setAppStatus(AppStatus status) → void
Update app status for testing
setAuthStatus(AppAuthStatus status) → void
Update auth status for testing
setColorThemeIndex(int index) Future<void>
inherited
setNetworkStatus(NetworkStatus status) → void
Update network status for testing different scenarios
toString() String
A string representation of this object.
inherited
updateNotificationPermissionStatus(NotificationPermissionStatus status) → void
Updates the notification permission status.
inherited
updateUnreadNotificationCount(int count) → void
Updates the unread notification count.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited