ListUtils class

Constructors

ListUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

doesContainContiguous<T>(List<int> list) → bool
isContiguous<T>(List<T> list, List<T> values) → bool
split<T>(List<T> list, int n) → List<List<T>>