BufferedBreadcrumb class

One breadcrumb captured (already gated + redacted) before the error reporter is attached. Held in Logger's _earlyBreadcrumbBuffer and flushed on attach (breadcrumbs-then-errors — ERH-032).

Constructors

BufferedBreadcrumb(String message, String? category, Map<String, dynamic>? data)
const

Properties

category String?
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited