setCustomErrorReporter static method

void setCustomErrorReporter(
  1. ErrorReporter? reporter
)

Set a custom error reporter for logging errors This is typically called automatically by the error handling initialization

Implementation

static void setCustomErrorReporter(ErrorReporter? reporter) {
  _customErrorReporter = reporter;
}