NetworkUtils class

Constructors

NetworkUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearCachedEmulatorAddress() → Future<void>
Manually clear the cached emulator address (for testing or troubleshooting)
discoverFirebaseEmulatorHost({int port = 5001}) → Future<String?>
Discovers the host machine's IP address for Firebase emulator
getDeviceIpAddress() → Future<String?>
Get the device's current IP address (for debugging) - returns first valid IP
getDeviceIpAddresses() → Future<List<String>>
Get all device IP addresses (for debugging and network discovery)