VersionUpdateInfo class

Constructors

VersionUpdateInfo({required VersionUpdateType updateType, required String currentVersion, required String requiredVersion, required String recommendedVersion, required String appStoreUrl})
const

Properties

appStoreUrl → String
final
currentVersion → String
final
hashCode → int
The hash code for this object.
no setterinherited
hasUpdate → bool
no setter
isRecommended → bool
no setter
isRequired → bool
no setter
recommendedVersion → String
final
requiredVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetVersion → String
no setter
updateType → VersionUpdateType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited