app/app_config_base
library
Enums
-
EnvironmentType
-
Environment types for build configuration
Can be set via --dart-define=ENVIRONMENT_TYPE=production
Typedefs
-
MobileEmailLinkActionCodeSettingsBuilder
= Future<ActionCodeSettings> Function()
-
Builder callback that fully owns construction of mobile email-link
ActionCodeSettings. Set this if your app uses Firebase Dynamic Links,
Firebase linkDomain, Branch, AppsFlyer, Adjust, or any other
deferred-deep-link product. When set, dreamic completely defers to this
callback and ignores emailConfirmMobileOrigin.