MobileEmailLinkActionCodeSettingsBuilder typedef
MobileEmailLinkActionCodeSettingsBuilder =
Future<ActionCodeSettings> Function()
Builder callback that fully owns construction of mobile email-link
ActionCodeSettings. Set this if your app uses Firebase Dynamic Links,
Firebase linkDomain, Branch, AppsFlyer, Adjust, or any other
deferred-deep-link product. When set, dreamic completely defers to this
callback and ignores emailConfirmMobileOrigin.
Implementation
typedef MobileEmailLinkActionCodeSettingsBuilder
= Future<fb_auth.ActionCodeSettings> Function();