AppCubit class
- Mixed-in types
- Implementers
Properties
- connectionChecker ↔ InternetConnection?
-
getter/setter pair
- connectionCheckerSubscription ↔ StreamSubscription?
-
getter/setter pair
- entranceUri ↔ Uri?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasProcessedEntrance ↔ bool
-
getter/setter pair
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
-
lifecycleSubscription
↔ StreamSubscription<
AppLifecycleState> ? -
getter/setter pair
- networkRequired ↔ bool
-
getter/setter pair
-
notificationBadgeSubscription
↔ StreamSubscription<
int> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → AppState
-
The current state.
no setterinherited
-
stream
→ Stream<
AppState> -
The current stream of states.
no setterinherited
-
versionUpdateSubscription
↔ StreamSubscription<
VersionUpdateInfo> ? -
getter/setter pair
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
checkForAppUpdates(
) → Future< void> -
clearUnreadNotificationCount(
) → void - Clears the unread notification count (sets to 0).
-
close(
) → Future< void> - Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
-
dismissVersionUpdateBanner(
) → void -
emit(
AppState state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
emitSafe(
AppState state) → void -
inherited
-
getInitialData(
) → Future< void> -
incrementUnreadNotificationCount(
) → void - Increments the unread notification count by 1.
-
initializeNotificationSync(
) → Future< void> - Initializes notification state sync with NotificationService.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< AppState> change) → void -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
overlayFullScreenFinish(
) → void -
overlayFullScreenSetChild(
Widget child()) → void -
overlayFullScreenSetChildAndStart(
Widget child()?) → void -
overlayFullScreenStart(
) → void -
overlayLoadingFinish(
) → void -
overlayLoadingStart(
) → void -
overlayProgressingFinish(
) → void -
overlayProgressingStart(
{String? headerText}) → void -
overlayProgressingUpdate(
double progress) → void -
refreshNotificationPermissionStatus(
) → Future< void> - Refreshes the notification permission status from the system.
-
requestNotificationPermissions(
{bool provisional = false}) → Future< NotificationPermissionStatus> - Requests notification permissions and syncs the result to state.
-
retryNetworkConnection(
) → Future< void> -
setColorThemeIndex(
int index) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateNotificationPermissionStatus(
NotificationPermissionStatus status) → void - Updates the notification permission status.
-
updateUnreadNotificationCount(
int count) → void - Updates the unread notification count.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited