DevicePlatformExtension extension

Extension to provide a displayable name for each platform.

on

Properties

displayName String

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns a human-readable display name for this platform.
no setter
isDesktop bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is a desktop platform (macOS, Windows, or Linux).
no setter
isMobile bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is a mobile platform (iOS or Android).
no setter
isWeb bool

Available on DevicePlatform, provided by the DevicePlatformExtension extension

Returns true if this is the web platform.
no setter