requiresAuth property
Whether this action requires the app to be unlocked/authenticated.
If true, the action will only be available when the device is unlocked (iOS) or may prompt for authentication (Android).
Implementation
@JsonKey(defaultValue: false)
final bool requiresAuth;