route property
Route or screen to navigate to when notification is tapped.
This value is passed to the onNotificationTapped callback.
The app is responsible for parsing and handling the route.
Implementation
final String? route;
Route or screen to navigate to when notification is tapped.
This value is passed to the onNotificationTapped callback.
The app is responsible for parsing and handling the route.
final String? route;