Methods
accessCodeCheckIfValid (String code )
→ Future <Either<RepositoryFailure , (AccessCodeCheckReturn , String ) > >
accessCodeIsValidCached ()
→ Future <Either<RepositoryFailure , bool > >
accessCodeRegisterWithEmailAndPassword (String email , String password )
→ Future <Either<AuthServiceSignInFailure , Unit > >
addOnAboutToLogOutCallback (Future <void > callback (), {int priority = 0 })
→ void
Add a callback to be invoked BEFORE logout while still authenticated.
addOnAuthenticatedCallback (Future <void > callback (String ? uid ), {int priority = 0 })
→ void
Add a callback to be invoked when user authenticates.
addOnLoggedOutCallback (Future <void > callback (), {int priority = 0 })
→ void
Add a callback to be invoked AFTER logout is complete.
applyActionCode (String oobCode )
→ Future <Either<AuthServiceActionCodeFailure , Unit > >
Apply (consume) a Firebase out-of-band action code. For an email-
verification oobCode, this flips the auth record's emailVerified to
true. The code is single-use; a second call with the same code returns
AuthServiceActionCodeFailure.invalidCode .
checkActionCode (String oobCode )
→ Future <Either<AuthServiceActionCodeFailure , ({String ? email } ) > >
Check (without consuming) a Firebase out-of-band action code — e.g. an
email-verification oobCode from a verification deep link — and return
the action's payload.
checkIfSignedInAndLoginAnonymouslyIfNot ()
→ Future <Either<AuthServiceSignInFailure , Unit > >
getUserClaims <T extends Enum > ({required List <T > enumValues , bool forceRefresh = false })
→ Future <Map <T , bool > >
Pass the UserClaims type to get the claims for that user
isEmailUser (String email )
→ Future <Either<AuthServiceSignInFailure , bool > >
isLoggedInAsync ()
→ Future <bool >
linkEmailPassword (String email , String password )
→ Future <Either<AuthServiceLinkFailure , Unit > >
Link anonymous account to email/password credentials
loginWithPhone (String phoneNumber , {required Function verificationCompleted , required dynamic verificationFailed (PhoneAuthError ), required Function codeSent , required Function codeAutoRetrievalTimeout , required bool codeResend })
→ Future <Either<PhoneAuthError , Unit > >
loginWithPhoneVerifyCode (String smsCode )
→ Future <Either<PhoneAuthError , bool > >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reauthenticateWithPassword (String password )
→ Future <Either<AuthServiceSignInFailure , Unit > >
Re-authenticate current user with password for sensitive operations
registerUserWithEmailAndPassword (String email , String password )
→ Future <Either<AuthServiceSignInFailure , Unit > >
registerUserWithJustEmail (String email )
→ Future <Either<AuthServiceSignInFailure , Unit > >
reloadUser ()
→ Future <Either<AuthServiceSignInFailure , Unit > >
Reload user data to get latest email verification status
removeOnAboutToLogOutCallback (Future <void > callback () )
→ bool
Remove a previously added logout callback.
Returns true if the callback was found and removed.
removeOnAuthenticatedCallback (Future <void > callback (String ? uid ) )
→ bool
Remove a previously added authenticated callback.
Returns true if the callback was found and removed.
removeOnLoggedOutCallback (Future <void > callback () )
→ bool
Remove a previously added logged out callback.
Returns true if the callback was found and removed.
resetPassword (String email )
→ Future <Either<AuthServiceSignInFailure , Unit > >
sendEmailVerification ([ActionCodeSettings? actionCodeSettings ])
→ Future <Either<AuthServiceEmailVerificationFailure , Unit > >
Send email verification to current user.
sendLoginEmail (String email )
→ Future <Either<AuthServiceSignInFailure , Unit > >
setPassword (String newPassword )
→ Future <Either<AuthServiceSignInFailure , Unit > >
signInWithCustomToken (String customToken )
→ Future <Either<AuthServiceSignInFailure , Unit > >
signInWithDevOnly ()
→ Future <Either<AuthServiceSignInFailure , Unit > >
signInWithEmail (String email )
→ Future <Either<AuthServiceSignInFailure , Unit > >
signInWithEmailAndPassword (String email , String password )
→ Future <Either<AuthServiceSignInFailure , Unit > >
signOut ()
→ Future <Either<AuthServiceSignOutFailure , Unit > >
toString ()
→ String
A string representation of this object.
inherited
updatePassword (String newPassword )
→ Future <Either<AuthServiceSignInFailure , Unit > >
Update the current user's password
validateEmailLink (String link , {String ? email })
→ Future <Either<AuthServiceEmailLinkFailure , Unit > >
waitForCanCheckLoginState ()
→ Future <bool >