NotificationPermissionBottomSheet constructor
const
NotificationPermissionBottomSheet({
- Key? key,
- String title = 'Enable Notifications',
- String description = 'Stay informed with notifications about important updates and activity.',
- String allowButtonText = 'Allow Notifications',
- String declineButtonText = 'Not Now',
- String deniedDialogTitle = 'Notifications Disabled',
- String deniedDialogMessage = 'To enable notifications, please go to Settings and allow notifications for this app.',
- String openSettingsButtonText = 'Open Settings',
- String maybeLaterButtonText = 'Maybe Later',
- Color? primaryColor,
- Color? backgroundColor,
- Widget? icon,
- dynamic onResult()?,
Implementation
const NotificationPermissionBottomSheet({
super.key,
this.title = 'Enable Notifications',
this.description = 'Stay informed with notifications about important updates and activity.',
this.allowButtonText = 'Allow Notifications',
this.declineButtonText = 'Not Now',
this.deniedDialogTitle = 'Notifications Disabled',
this.deniedDialogMessage =
'To enable notifications, please go to Settings and allow notifications for this app.',
this.openSettingsButtonText = 'Open Settings',
this.maybeLaterButtonText = 'Maybe Later',
this.primaryColor,
this.backgroundColor,
this.icon,
this.onResult,
});