AsyncThrottler class
Async throttling with process-based locking.
Constructors
- AsyncThrottler({Duration? maxDuration, bool enabled = true, bool resetOnError = false, bool debugMode = false, String? name, void onMetrics(Duration executionTime)?, TimerFactory? timerFactory})
Properties
- debugMode → bool
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLocked → bool
-
no setter
- maxDuration → Duration?
-
final
- name → String?
-
final
- onMetrics → void Function(Duration executionTime)?
-
final
- resetOnError → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
Future< void> callback()) → Future<void> -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
Future< void> callback()?) → VoidCallback? - Wrap a nullable callback for use with builder widgets.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited