CallbackController class abstract
Base class for synchronous callback controllers (Throttler, Debouncer).
Constructors
- CallbackController({required Duration duration, bool enabled = true, bool debugMode = false, String? name, TimerFactory? timerFactory})
Properties
- debugMode → bool
-
final
- duration → Duration
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPending → bool
-
Whether an operation is pending.
no setter
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timer ↔ Timer?
-
getter/setter pair
Methods
-
call(
VoidCallback callback) → void - Execute the callback with timing control.
-
callWithDuration(
VoidCallback callback, Duration customDuration) → void - Execute with a custom duration (overrides default).
-
cancel(
) → void - Cancel pending operations.
-
createTimer(
Duration duration, VoidCallback callback) → Timer -
debugLog(
String message) → void -
dispose(
) → void - Full cleanup.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
VoidCallback? callback) → VoidCallback? - Wrap a nullable callback for use with listeners.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited