TapMetrics class
Metrics data for tap analytics and observability.
- Annotations
Constructors
- TapMetrics({required Duration executionDuration, required bool wasThrottled, required bool wasCancelled, required bool hadError, required int tapCountInWindow, String? groupId, required TapExecutionMode executionMode, required DateTime timestamp})
-
const
Properties
- executionDuration → Duration
-
final
- executionMode → TapExecutionMode
-
final
- groupId → String?
-
final
- hadError → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tapCountInWindow → int
-
final
- timestamp → DateTime
-
final
- wasCancelled → bool
-
final
- wasThrottled → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override