ThrottleDebouncer class
Combines throttle + debounce: executes immediately (leading edge), then again after pause (trailing edge).
Constructors
- ThrottleDebouncer({Duration duration = defaultDuration, TimerFactory? timerFactory})
Properties
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPendingCallback → bool
-
no setter
- isPending → bool
-
no setter
- isThrottled → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
VoidCallback callback) → void -
callWithDuration(
VoidCallback callback, Duration customDuration) → void -
cancel(
) → void -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
VoidCallback? callback) → VoidCallback? - Wrap a nullable callback for use with listeners.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultDuration → const Duration