setCustomErrorReporter static method
Set a custom error reporter for logging errors This is typically called automatically by the error handling initialization
Implementation
static void setCustomErrorReporter(ErrorReporter? reporter) {
_customErrorReporter = reporter;
}