PasswordComplexity enum
Password complexity presets for validation.
Values
- sixCharAnything → const PasswordComplexity
-
Minimum 6 characters, no other requirements. Suitable for family-friendly apps with simple password needs.
- eightChar1Letter1Number → const PasswordComplexity
-
Minimum 8 characters, at least 1 letter and 1 number. Default complexity level for most applications.
- eight2Upper2Number2Special → const PasswordComplexity
-
Minimum 8 characters, at least 2 uppercase, 2 numbers, and 2 special characters. High security for sensitive applications.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PasswordComplexity> - A constant List of the values in this enum, in order of their declaration.